@@ -3,7 +3,7 @@ package Pisg;
 # Documentation(POD) for this module is found at the end of the file.
 
 # Copyright (C) 2001-2005  <Morten Brix Pedersen> - morten@wtf.dk
-# Copyright (C) 2003-2005  Christoph Berg <cb@df7cb.de>
+# Copyright (C) 2003-2006  Christoph Berg <cb@df7cb.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -57,15 +57,19 @@ sub run
     # Init the configuration file (aliases, ignores, channels, etc)
     my $r;
     if ($self->{use_configfile}) {
-        if ((open(CONFIG, $self->{cfg}->{configfile}) 
-            or open(CONFIG, $self->{search_path} . "/$self->{cfg}->{configfile}"))) {
-            $r = $self->init_config(\*CONFIG)
+        foreach my $c ($self->{cfg}->{configfile}, $self->{search_path} . "/$self->{cfg}->{configfile}") {
+            if (open(CONFIG, $c)) {
+                $self->{cfg}->{configfile} = $c;
+                print "Using config file: $self->{cfg}->{configfile}\n\n"
+                    unless ($self->{cfg}->{silent});
+                $r = $self->init_config(\*CONFIG);
+                last;
+            } else {
+                print STDERR "Warning: $c: $!\n\n" if -e $c;
+            }
         }
     }
 
-    print "Using config file: $self->{cfg}->{configfile}\n\n"
-        if ($r && !$self->{cfg}->{silent});
-
     # Get translations from langfile
     $self->get_language_templates();
 
@@ -215,7 +219,7 @@ sub get_default_config_settings
         modules_dir => '',         # set in get_cmdline_options
         cchannels => '',           # set in get_cmdline_options
 
-        version => "0.67",
+        version => "0.68",
     };
 
     # This enables us to use the search_path in other modules
@@ -279,7 +283,7 @@ sub init_config
         if ($line =~ /<user.*>/) {
             my $nick;
 
-            if ($line =~ /nick=(["'])(.+?)\1/) {
+            if ($line =~ /\bnick=(["'])(.+?)\1/) {
                 $nick = $2;
                 add_alias($nick, $nick);
             } else {
@@ -287,7 +291,7 @@ sub init_config
                 next;
             }
 
-            if ($line =~ /alias=(["'])(.+?)\1/) {
+            if ($line =~ /\balias=(["'])(.+?)\1/) {
                 my @thisalias = split(/\s+/, lc($2));
                 foreach (@thisalias) {
                     if ($self->{cfg}->{regexpaliases} and /[\|\[\]\{\}\(\)\?\+\.\*\^\\]/) {
@@ -302,28 +306,28 @@ sub init_config
                 }
             }
 
-            if ($line =~ /pic=(["'])(.+?)\1/) {
+            if ($line =~ /\bpic=(["'])(.+?)\1/) {
                 $self->{users}->{userpics}{$nick} = $2;
             }
 
-            if ($line =~ /bigpic=(["'])(.+?)\1/) {
+            if ($line =~ /\bbigpic=(["'])(.+?)\1/) {
                 $self->{users}->{biguserpics}{$nick} = $2;
             }
 
-            if ($line =~ /link=(["'])(.+?)\1/) {
+            if ($line =~ /\blink=(["'])(.+?)\1/) {
                 $self->{users}->{userlinks}{$nick} = $2;
             }
 
-            if ($line =~ /ignore=(["'])Y\1/i) {
+            if ($line =~ /\bignore=(["'])Y\1/i) {
                 add_ignore($nick);
             }
 
-            if ($line =~ /sex=(["'])([MmFfBb])\1/) {
+            if ($line =~ /\bsex=(["'])([MmFfBb])\1/) {
                 $self->{users}->{sex}{$nick} = lc($2);
             }
         } elsif ($line =~ /<link(.*)>/) {
 
-            if ($line =~ /url=(["'])(.+?)\1/) {
+            if ($line =~ /\burl=(["'])(.+?)\1/) {
                 my $url = $2;
                 if ($line =~ /ignore="Y"/i) {
                     add_url_ignore($url);
@@ -342,13 +346,16 @@ sub init_config
 
             while ($settings =~ s/[ \t]([^=]+?)=(["'])(.*?)\2//) {
                 my $var = lc($1);
+                my $val = $3;
                 $var =~ s/ //; # Remove whitespace
+
                 if (!defined($self->{cfg}->{$var})) {
                     print STDERR "Warning: $self->{cfg}->{configfile}, line $.: No such configuration option: '$var'\n";
                     next;
                 }
-                unless (($self->{cfg}->{$var} eq $3) || $self->{override_cfg}->{$var}) {
-                    $self->{cfg}->{$var} = $3;
+
+                unless (($self->{cfg}->{$var} eq $val) || $self->{override_cfg}->{$var}) {
+                    $self->{cfg}->{$var} = $val;
                 }
             }
 
@@ -356,12 +363,13 @@ sub init_config
             my ($channel, $settings, $tmp) = ($2, $3, {});
             $tmp->{$channel}->{channel} = $channel;
             $self->{cfg}->{chan_done}{$self->{cfg}->{channel}} = 1; # don't parse channel in $self->{cfg}->{channel} if a channel statement is present
-            while ($settings =~ s/\s([^=]+)=(["'])(.+?)\2//) {
+            while ($settings =~ s/\s([^=]+)=(["'])(.*?)\2//) {
                 my $var = lc($1);
+                my $val = $3;
                 if ($var eq "logdir" || $var eq "logfile") {
-                    push(@{$tmp->{$channel}{$var}}, $3);
+                    push(@{$tmp->{$channel}{$var}}, $val);
                 } else {
-                    $tmp->{$channel}{$var} = $3;
+                    $tmp->{$channel}{$var} = $val;
                 }
             }
             while (<$fh>) {
@@ -370,14 +378,15 @@ sub init_config
                     push @{ $self->{chans} }, $tmp;
                     last;
                 }
-                if ($_ =~ /^\s*(\w+)\s*=\s*(["'])(.+?)\2/) {
+                if ($_ =~ /^\s*(\w+)\s*=\s*(["'])(.*?)\2/) {
                     my $var = lc($1);
+                    my $val = $3;
                     unless ((($var eq "logdir" || $var eq "logfile") && scalar(@{$self->{override_cfg}->{$var}}) > 0) || (($var ne "logdir" && $var ne "logfile") && $self->{override_cfg}->{$var})) {
 
                         if($var eq "logdir" || $var eq "logfile") {
-                            push @{$tmp->{$channel}{$var}}, $3;
+                            push @{$tmp->{$channel}{$var}}, $val;
                         } else {
-                            $tmp->{$channel}{$var} = $3;
+                            $tmp->{$channel}{$var} = $val;
                         }
 
                     }
@@ -390,14 +399,20 @@ sub init_config
             my $backup_cfg = $self->{cfg}->{configfile};
             $self->{cfg}->{configfile} = $include_cfg;
             my $r;
-            if ((open(INCLUDE, $self->{cfg}->{configfile}) 
-                or open(INCLUDE, $self->{search_path} . "/$self->{cfg}->{configfile}"))) {
-                $r = $self->init_config(\*INCLUDE);
-            } else {
-                print STDERR "Warning: $backup_cfg, line $.: $self->{cfg}->{configfile}: $!\n";
+            foreach my $c ($self->{cfg}->{configfile}, $self->{search_path} . "/$self->{cfg}->{configfile}") {
+                if (open(INCLUDE, $c)) {
+                    $self->{cfg}->{configfile} = $c;
+                    $r = $self->init_config(\*INCLUDE);
+                    last;
+                } else {
+                    print STDERR "Warning: $backup_cfg, line $.: $c: $!\n"
+                        if -e $c;
+                }
             }
             print "Included config file: $self->{cfg}->{configfile}\n\n"
                 if ($r && !$self->{cfg}->{silent});
+            print STDERR "Warning: $backup_cfg, line $.: $self->{cfg}->{configfile} not found\n"
+                if (!$r);
             $self->{cfg}->{configfile} = $backup_cfg;
         } elsif ($line =~ /<(\w+)?.*[^>]$/) {
             print STDERR "Warning: $self->{cfg}->{configfile}, line $.: Missing end on element <$1 (probably multi-line?)\n";
@@ -427,9 +442,6 @@ sub init_pisg
     }
     $self->{cfg}->{timestamp} = $timestamp;
 
-    $self->{cfg}->{lang} = uc $self->{cfg}->{lang};
-    $self->{cfg}->{lang} =~ s/-/_/g; # PT_BR was called PT-BR before
-
     # convert wordlists
     $self->{cfg}->{foulwords} = wordlist_regexp($self->{cfg}->{foulwords}, $self->{cfg}->{regexpaliases});
     $self->{cfg}->{ignorewords} = wordlist_regexp($self->{cfg}->{ignorewords}, $self->{cfg}->{regexpaliases});
@@ -452,9 +464,6 @@ sub init_pisg
 
     unless ($self->{cfg}->{silent}) {
         print "Statistics for channel $self->{cfg}->{channel} \@ $self->{cfg}->{network} by $self->{cfg}->{maintainer}\n\n";
-        die sprintf "No such language: %s\n", $self->{cfg}->{lang}
-            unless $self->{tmps}->{$self->{cfg}->{lang}};
-        print "Using language template: $self->{cfg}->{lang}\n\n" if $self->{cfg}->{lang} ne 'EN';
     }
 }
 
@@ -510,7 +519,11 @@ _END
         # Create our HTML page if the logfile has any data.
         if (defined $stats) {
             if ($stats->{parsedlines} > 0) {
-                $generator->create_output();
+                foreach my $lang (split /\s*,\s*/, uc $self->{cfg}->{lang}) {
+                    $lang =~ s/-/_/g; # PT_BR was called PT-BR before
+                    die sprintf "No such language: %s\n", $_ unless $self->{tmps}->{$lang};
+                    $generator->create_output($lang);
+                }
             } else {
                 print STDERR <<_END unless $self->{cfg}->{silent};
 No parseable lines found in logfile ($stats->{totallines} total lines). Skipping.
