@@ -1,6 +1,6 @@
 package Pisg::HTMLGenerator;
 
-# $Id: HTMLGenerator.pm,v 1.172 2005/08/11 17:38:36 df7cb Exp $
+# $Id: HTMLGenerator.pm,v 1.174 2005/08/23 10:16:02 df7cb Exp $
 #
 # Copyright and license, as well as documentation(POD) for this module is
 # found at the end of the file.
@@ -29,17 +29,6 @@ sub new
     require Pisg::Common;
     Pisg::Common->import();
 
-    my $lang_charset = $self->{tmps}->{$self->{cfg}->{lang}}{lang_charset};
-    if($lang_charset and $lang_charset ne $self->{cfg}->{charset}) {
-        if($have_iconv) {
-            # convert from template charset to our
-            $self->{iconv} = Text::Iconv->new($lang_charset, $self->{cfg}->{charset});
-        } else {
-            print "Text::Iconv is not installed, skipping charset conversion of language templates\n"
-                unless ($self->{cfg}->{silent});
-        }
-    }
-
     bless($self, $type);
     return $self;
 }
@@ -52,6 +41,18 @@ sub create_output
     # sub itself.
 
     my $self = shift;
+    $self->{cfg}->{lang} = shift;
+
+    my $lang_charset = $self->{tmps}->{$self->{cfg}->{lang}}{lang_charset};
+    if($lang_charset and $lang_charset ne $self->{cfg}->{charset}) {
+        if($have_iconv) {
+            # convert from template charset to our
+            $self->{iconv} = Text::Iconv->new($lang_charset, $self->{cfg}->{charset});
+        } else {
+            print "Text::Iconv is not installed, skipping charset conversion of language templates\n"
+                unless ($self->{cfg}->{silent});
+        }
+    }
 
     $self->_topactive();
 
@@ -61,7 +62,8 @@ sub create_output
 
     my $fname = $self->{cfg}->{outputfile};
     $fname =~ s/\%t/$self->{cfg}->{outputtag}/g;
-    print "Now generating HTML in $fname...\n"
+    $fname =~ s/\%l/$self->{cfg}->{lang}/g;
+    print "Now generating HTML ($self->{cfg}->{lang}) in $fname...\n"
         unless ($self->{cfg}->{silent});
 
     open (OUTPUT, "> $fname") or
@@ -561,10 +563,7 @@ sub _activenicks
             $visiblenick = $self->_format_word($nick);
         }
 
-        my $style = '';
-        if ($self->{cfg}->{colorscheme} ne 'none') {
-            $style = "style=\"background-color: ". $self->generate_colors($c) ."\"";
-        }
+        my $style = $self->generate_colors($c);
 
         my $class = 'rankc';
         if ($c == 1) {
@@ -683,10 +682,10 @@ sub generate_colors
     my $self = shift;
     my $c = shift;
 
-    my $h = $self->{cfg}->{hicell};
+    my $h = $self->{cfg}->{hicell} or return "class=\"hicell\"";
     $h =~ s/^#//;
     $h = hex $h;
-    my $h2 = $self->{cfg}->{hicell2};
+    my $h2 = $self->{cfg}->{hicell2} or return "class=\"hicell\"";
     $h2 =~ s/^#//;
     $h2 = hex $h2;
     my $f_b = $h & 0xff;
@@ -699,7 +698,7 @@ sub generate_colors
     my $green  = sprintf "%0.2x", abs int(((($t_g - $f_g) / $self->{cfg}->{activenicks}) * +$c) + $f_g);
     my $red  = sprintf "%0.2x", abs int(((($t_r - $f_r) / $self->{cfg}->{activenicks}) * +$c) + $f_r);
 
-    return "#$red$green$blue";
+    return "style=\"background-color: #$red$green$blue\"";
 }
 
 sub _html
