@@ -399,14 +399,14 @@ sub _parse_file
                     my $e = '[8;:=%]'; # eyes
                     my $n = '[-oc*^]'; # nose
                     # smileys including asian-style (^^ ^_^' ^^; \o/)
-                    if ($saying =~ /(>?$e'?$n[\)pPD\}\]>]|[\(\{\[<]$n'?$e<?|[;:]\)|\([;:]|\^[_o-]*\^[';]|\\[o.]\/)/o) {
+                    if ($saying =~ /(>?$e'?$n[\)pPD\}\]>]|[\(\{\[<]$n'?$e<?|[;:][\)pPD\}\]\>]|\([;:]|\^[_o-]*\^[';]|\\[o.]\/)/o) {
                         $stats->{smiles}{$nick}++;
                         $stats->{smileys}{$1}++;
                         $stats->{smileynicks}{$1} = $nick;
                     }
 
                     # asian frown: ;_;
-                    if ($saying =~ /($e'?$n[\(\[\\\/\{|]|[\)\]\\\/\}|]$n'?$e|[;:]\(|\):|;_+;|T_+T|-[._]+-)/o and
+                    if ($saying =~ /($e'?$n[\(\[\\\/\{|]|[\)\]\\\/\}|]$n'?$e|[;:][\(\/]|[\)D]:|;_+;|T_+T|-[._]+-)/o and
                         $saying !~ /\w+:\/\//o) {
                         $stats->{frowns}{$nick}++;
                         $stats->{smileys}{$1}++;
@@ -662,6 +662,7 @@ sub _charts
     $Song =~ s/_/ /g;
     $Song =~ s/\d+ ?- ?//;
     $Song =~ s/\.(mp3|ogg|wma)//ig;
+    $Song =~ s/\[[^\] ]*\]/ /g; # strip stuff in brackets [44kbps]
     $Song =~ s/^ *[^\w]* *| *[^\w]* *$//g;
     my $song = lc $Song;
     $stats->{word_upcase}{$song} = $Song;
